@@ -28,8 +28,9 @@
  * WWW URL: http://cs.nyu.edu/exact/
  * Email: exact@cs.nyu.edu
  *
- * $URL$
- * $Id$
+ * $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/CGAL_Core/include/CGAL/CORE/CoreAux.h $
+ * $Id: CoreAux.h 6b568a8 2017-11-11T21:06:17+01:00 Sébastien Loriot
+ * SPDX-License-Identifier: LGPL-3.0+
  ***************************************************************************/
 
 #ifndef _CORE_COREAUX_H_
@@ -62,7 +63,7 @@ namespace CORE {
 const double relEps = (1.0 + std::ldexp(1.0, -52));
 
 /// CORE_DIAGFILE is used for all warning and error messages
-extern const char* CORE_DIAGFILE;
+const char* const CORE_DIAGFILE = "Core_Diagnostics";  // global file name
 
 /// template function returns the maximum value of two
 template <class T>
