@@ -12,8 +12,9 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Arrangement_on_surface_2/include/CGAL/Curved_kernel_via_analysis_2/test/simple_models.h $
+// $Id: simple_models.h 26c857a 2018-06-13T15:11:45+02:00 Mael Rouxel-Labbé
+// SPDX-License-Identifier: LGPL-3.0+
 //
 //
 // Author(s)     : Pavel Emeliyanenko <asm@mpi-sb.mpg.de>
@@ -21,9 +22,6 @@
 #ifndef CGAL_CURVED_KERNEL_VIA_ANALYSIS_2_TEST_SIMPLE_MODELS_H
 #define CGAL_CURVED_KERNEL_VIA_ANALYSIS_2_TEST_SIMPLE_MODELS_H
 
-#include <CGAL/license/Arrangement_on_surface_2.h>
-
-
 /*!\file include/CGAL/Curved_kernel_via_analysis_2/test/simple_models.h
  * \brief defines dummy implementations satisfying Curve_kernel_2
  * concept requirenments 
@@ -1043,7 +1041,7 @@ public:
     
     //! \brief constructs \c Curve_analysis_2 object, uses caching if appropriate
     struct Construct_curve_2 :
-            public std::unary_function< Polynomial_2, Curve_analysis_2 >
+            public CGAL::cpp98::unary_function< Polynomial_2, Curve_analysis_2 >
     {
         //! \brief constructs an object from \c Algebraic_curve_kernel_2 type
         //! no default constructor provided
@@ -1062,7 +1060,7 @@ public:
      * caching is used when appropriate
      */
     struct Construct_curve_pair_2 :
-            public std::binary_function<Curve_analysis_2, Curve_analysis_2,
+            public CGAL::cpp98::binary_function<Curve_analysis_2, Curve_analysis_2,
                 Curve_pair_analysis_2> {
            
         Curve_pair_analysis_2 operator()
@@ -1080,7 +1078,7 @@ public:
     
     //! returns the first coordinate of \c Xy_coordinate_2
     struct Get_x_2 :
-        public std::unary_function<Xy_coordinate_2, Algebraic_real_1> {
+        public CGAL::cpp98::unary_function<Xy_coordinate_2, Algebraic_real_1> {
         
         Algebraic_real_1 operator()(const Xy_coordinate_2& xy) const {
             return xy.x();
@@ -1090,7 +1088,7 @@ public:
     
     //! returns the second coordinate of \c Xy_coordinate_2
     struct Get_y_2 :
-        public std::unary_function<Xy_coordinate_2, Algebraic_real_1> {
+        public CGAL::cpp98::unary_function<Xy_coordinate_2, Algebraic_real_1> {
         
         Algebraic_real_1 operator()(const Xy_coordinate_2& xy) const {
             return xy.y();
@@ -1099,7 +1097,7 @@ public:
     CGAL_Algebraic_Kernel_cons(Get_y_2, Get_y_2_object);
     
     struct Refine_x_2 :
-        public std::unary_function<Xy_coordinate_2, void> {
+        public CGAL::cpp98::unary_function<Xy_coordinate_2, void> {
       
         void operator()(const Xy_coordinate_2& r) const {  }
         
@@ -1108,7 +1106,7 @@ public:
     CGAL_Algebraic_Kernel_pred(Refine_x_2, refine_x_2_object);
     
     struct Refine_y_2 :
-        public std::unary_function<Xy_coordinate_2, void> {
+        public CGAL::cpp98::unary_function<Xy_coordinate_2, void> {
       
         void operator()(const Xy_coordinate_2& r) const {  }
         
@@ -1198,7 +1196,7 @@ public:
     
     //! \brief comparison of x-coordinates 
     struct Compare_x_2 :
-         public std::binary_function<Algebraic_real_1, Algebraic_real_1, 
+         public CGAL::cpp98::binary_function<Algebraic_real_1, Algebraic_real_1,
                 Comparison_result > {
 
         Comparison_result operator()(const Algebraic_real_1& x1, 
@@ -1214,7 +1212,7 @@ public:
 
     //! \brief comparison of y-coordinates of two points
     struct Compare_y_2 :
-        public std::binary_function< Xy_coordinate_2, Xy_coordinate_2, 
+        public CGAL::cpp98::binary_function< Xy_coordinate_2, Xy_coordinate_2,
                 Comparison_result > {
         
         Comparison_result operator()(const Xy_coordinate_2& xy1, 
@@ -1228,7 +1226,7 @@ public:
     //!
     //! \c equal_x specifies that only y-coordinates need to be compared
     struct Compare_xy_2 :
-          public std::binary_function<Xy_coordinate_2, Xy_coordinate_2, 
+          public CGAL::cpp98::binary_function<Xy_coordinate_2, Xy_coordinate_2,
                 Comparison_result > 
     {
         Comparison_result operator()(const Xy_coordinate_2& xy1, 
@@ -1245,7 +1243,7 @@ public:
     //! for algerbaic curves this means that supporting polynomial is 
     //! square-free
     struct Has_finite_number_of_self_intersections_2 :
-            public std::unary_function< Polynomial_2, bool > {
+            public CGAL::cpp98::unary_function< Polynomial_2, bool > {
 
         bool operator()(const Polynomial_2& p) const {
             return true; //is_square_free(p);
@@ -1260,7 +1258,7 @@ public:
     //! in case of algerbaic curves: checks whether supporting polynomials are
     //! coprime
     struct Has_finite_number_of_intersections_2 :
-        public std::binary_function< Curve_analysis_2, Curve_analysis_2, bool > { 
+        public CGAL::cpp98::binary_function< Curve_analysis_2, Curve_analysis_2, bool > {
                
         bool operator()(const Curve_analysis_2& c1, 
                         const Curve_analysis_2& c2) const {
@@ -1317,7 +1315,7 @@ public:
     
     //! \brief computes the derivative w.r.t. the first (innermost) variable
     struct Derivative_x_2 : 
-        public std::unary_function< Polynomial_2, Polynomial_2 > {
+        public CGAL::cpp98::unary_function< Polynomial_2, Polynomial_2 > {
         
         Polynomial_2 operator()(const Polynomial_2& p) const {
             return p;
@@ -1327,7 +1325,7 @@ public:
 
     //! \brief computes the derivative w.r.t. the first (outermost) variable
     struct Derivative_y_2 :
-        public std::unary_function< Polynomial_2, Polynomial_2 > {
+        public CGAL::cpp98::unary_function< Polynomial_2, Polynomial_2 > {
         
         Polynomial_2 operator()(const Polynomial_2& p) const  {
             return p;
@@ -1376,7 +1374,7 @@ public:
      * returns a value convertible to \c CGAL::Sign
      */
     struct Sign_at_2 :
-        public std::binary_function< Polynomial_2, Xy_coordinate_2, Sign > {
+        public CGAL::cpp98::binary_function< Polynomial_2, Xy_coordinate_2, Sign > {
 
         Sign operator()(const Polynomial_2& p, const Xy_coordinate_2& r) const
         {
