@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Spatial_sorting/include/CGAL/Hilbert_sort_middle_d.h $
+// $Id: Hilbert_sort_middle_d.h 26c857a 2018-06-13T15:11:45+02:00 Mael Rouxel-Labbé
 // SPDX-License-Identifier: LGPL-3.0+
 //
 // Author(s)     :  Olivier Devillers
@@ -33,7 +33,7 @@ namespace internal {
 
     template <class K>
     struct Fixed_hilbert_cmp_d
-        : public CGAL::binary_function<typename K::Point_d,
+        : public CGAL::cpp98::binary_function<typename K::Point_d,
                                       typename K::Point_d, bool>
     {
         typedef typename K::Point_d Point;
