@@ -12,8 +12,9 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Mesh_3/include/CGAL/Mesh_3/Null_perturber_visitor.h $
+// $Id: Null_perturber_visitor.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0+
 //
 //
 // Author(s)     : Stephane Tayeb
@@ -25,6 +26,9 @@
 #ifndef CGAL_MESH_3_NULL_PERTURBER_VISITOR_H
 #define CGAL_MESH_3_NULL_PERTURBER_VISITOR_H
 
+#include <CGAL/license/Mesh_3.h>
+
+
 #include <cstddef>
 
 namespace CGAL {
