@@ -12,8 +12,9 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Nef_3/include/CGAL/Nef_3/Default_items.h $
+// $Id: Default_items.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0+
 // 
 //
 // Author(s)     : Andreas Fabri <andreas.fabri@geometryfactory.com>
@@ -21,6 +22,9 @@
 #ifndef CGAL_NEF_DEFAULT_ITEMS_H
 #define CGAL_NEF_DEFAULT_ITEMS_H
 
+#include <CGAL/license/Nef_3.h>
+
+
 #include <CGAL/Nef_3/SNC_items.h>
 #include <CGAL/Nef_3/SNC_indexed_items.h>
 #include <CGAL/Extended_homogeneous.h>
