@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/corefinement.h $
-// $Id: corefinement.h 2583258 %aI Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/corefinement.h $
+// $Id: corefinement.h aa47744 2019-07-28T22:30:17+02:00 Sébastien Loriot
 // SPDX-License-Identifier: GPL-3.0+
 //
 //
@@ -193,10 +193,10 @@ bool does_bound_a_volume(const TriangleMesh& tm, const NamedParameters& np)
   if (!is_closed(tm)) return false;
   if (!is_triangle_mesh(tm)) return false;
 
-  Vpm vpm = boost::choose_param(boost::get_param(np, internal_np::vertex_point),
+  Vpm vpm = parameters::choose_parameter(parameters::get_parameter(np, internal_np::vertex_point),
                                 get_const_property_map(boost::vertex_point, tm));
 
-  Fid_map fid_map = boost::choose_param(boost::get_param(np, internal_np::face_index),
+  Fid_map fid_map = parameters::choose_parameter(parameters::get_parameter(np, internal_np::face_index),
                                         get_const_property_map(boost::face_index, tm));
 
   std::vector<std::size_t> face_cc(num_faces(tm), std::size_t(-1));
@@ -249,13 +249,13 @@ bool does_bound_a_volume(const TriangleMesh& tm)
 /// \endcond
 
 #define CGAL_COREF_SET_OUTPUT_EDGE_MARK_MAP(I) \
-  typedef typename boost::lookup_named_param_def < \
+  typedef typename internal_np::Lookup_named_param_def < \
     internal_np::edge_is_constrained_t, \
     NamedParametersOut##I, \
     Corefinement::No_mark<TriangleMesh> \
   > ::type Ecm_out_##I; \
     Ecm_out_##I ecm_out_##I = \
-      boost::choose_param( boost::get_param(cpp11::get<I>(nps_out), internal_np::edge_is_constrained),  \
+      parameters::choose_parameter( parameters::get_parameter(cpp11::get<I>(nps_out), internal_np::edge_is_constrained),  \
                            Corefinement::No_mark<TriangleMesh>() );
 
 
@@ -361,7 +361,7 @@ corefine_and_compute_boolean_operations(
                      NamedParametersOut3>& nps_out)
 {
   const bool throw_on_self_intersection =
-    boost::choose_param(boost::get_param(np1, internal_np::throw_on_self_intersection), false);
+    parameters::choose_parameter(parameters::get_parameter(np1, internal_np::throw_on_self_intersection), false);
 
 // Vertex point maps
   //for input meshes
@@ -374,10 +374,10 @@ corefine_and_compute_boolean_operations(
     static const bool same_vpm = (boost::is_same<Vpm,Vpm2>::value); )
   CGAL_static_assertion(same_vpm);
 
-  Vpm vpm1 = boost::choose_param(boost::get_param(np1, internal_np::vertex_point),
+  Vpm vpm1 = parameters::choose_parameter(parameters::get_parameter(np1, internal_np::vertex_point),
                                  get_property_map(boost::vertex_point, tm1));
 
-  Vpm vpm2 = boost::choose_param(boost::get_param(np2, internal_np::vertex_point),
+  Vpm vpm2 = parameters::choose_parameter(parameters::get_parameter(np2, internal_np::vertex_point),
                                  get_property_map(boost::vertex_point, tm2));
 
   typedef typename boost::property_traits<Vpm>::value_type Point_3;
@@ -494,21 +494,21 @@ corefine_and_compute_boolean_operations(
 
 // Edge is-constrained maps
   //for input meshes
-  typedef typename boost::lookup_named_param_def <
+  typedef typename internal_np::Lookup_named_param_def <
     internal_np::edge_is_constrained_t,
     NamedParameters1,
     Corefinement::No_mark<TriangleMesh>//default
   > ::type Ecm1;
 
-  typedef typename boost::lookup_named_param_def <
+  typedef typename internal_np::Lookup_named_param_def <
     internal_np::edge_is_constrained_t,
     NamedParameters2,
     Corefinement::No_mark<TriangleMesh>//default
   > ::type Ecm2;
 
-  Ecm1 ecm1 = boost::choose_param( boost::get_param(np1, internal_np::edge_is_constrained),
+  Ecm1 ecm1 = parameters::choose_parameter( parameters::get_parameter(np1, internal_np::edge_is_constrained),
                                    Corefinement::No_mark<TriangleMesh>() );
-  Ecm2 ecm2 = boost::choose_param( boost::get_param(np2, internal_np::edge_is_constrained),
+  Ecm2 ecm2 = parameters::choose_parameter( parameters::get_parameter(np2, internal_np::edge_is_constrained),
                                    Corefinement::No_mark<TriangleMesh>() );
 
   typedef Corefinement::Ecm_bind<TriangleMesh, Ecm1, Ecm2> Ecm_in;
@@ -533,17 +533,17 @@ corefine_and_compute_boolean_operations(
     static const bool same_fidmap = (boost::is_same<Fid_map,Fid_map2>::value);)
   CGAL_static_assertion(same_fidmap);
 
-  Fid_map fid_map1 = boost::choose_param(boost::get_param(np1, internal_np::face_index),
+  Fid_map fid_map1 = parameters::choose_parameter(parameters::get_parameter(np1, internal_np::face_index),
                                         get_property_map(boost::face_index, tm1));
-  Fid_map fid_map2 = boost::choose_param(boost::get_param(np2, internal_np::face_index),
+  Fid_map fid_map2 = parameters::choose_parameter(parameters::get_parameter(np2, internal_np::face_index),
                                          get_property_map(boost::face_index, tm2));
 // User visitor
-  typedef typename boost::lookup_named_param_def <
+  typedef typename internal_np::Lookup_named_param_def <
     internal_np::graph_visitor_t,
     NamedParameters1,
     Corefinement::Default_visitor<TriangleMesh>//default
   > ::type User_visitor;
-  User_visitor uv( boost::choose_param( boost::get_param(np1, internal_np::graph_visitor),
+  User_visitor uv( parameters::choose_parameter( parameters::get_parameter(np1, internal_np::graph_visitor),
                    Corefinement::Default_visitor<TriangleMesh>() ) );
 
   // surface intersection algorithm call
@@ -564,7 +564,7 @@ corefine_and_compute_boolean_operations(
         vpm_out_tuple, ecms_out, uv, output);
 
   // special case used for clipping open meshes
-  if (  boost::choose_param( boost::get_param(np1, internal_np::use_bool_op_to_clip_surface),
+  if (  parameters::choose_parameter( parameters::get_parameter(np1, internal_np::use_bool_op_to_clip_surface),
                              false) )
   {
     CGAL_assertion(output[Corefinement::INTERSECTION] != boost::none);
@@ -572,7 +572,7 @@ corefine_and_compute_boolean_operations(
     CGAL_assertion(output[Corefinement::TM1_MINUS_TM2] == boost::none);
     CGAL_assertion(output[Corefinement::TM2_MINUS_TM1] == boost::none);
     const bool use_compact_clipper =
-      boost::choose_param( boost::get_param(np1, internal_np::use_compact_clipper),
+      parameters::choose_parameter( parameters::get_parameter(np1, internal_np::use_compact_clipper),
                            true);
     ob.setup_for_clipping_a_surface(use_compact_clipper);
   }
@@ -841,7 +841,7 @@ corefine_and_compute_difference(      TriangleMesh& tm1,
           const NamedParameters2& np2)
 {
   const bool throw_on_self_intersection =
-    boost::choose_param(boost::get_param(np1, internal_np::throw_on_self_intersection), false);
+    parameters::choose_parameter(parameters::get_parameter(np1, internal_np::throw_on_self_intersection), false);
 
 // Vertex point maps
   typedef typename GetVertexPointMap<TriangleMesh,
@@ -853,28 +853,28 @@ corefine_and_compute_difference(      TriangleMesh& tm1,
     static const bool same_vpm = (boost::is_same<Vpm,Vpm2>::value);)
   CGAL_static_assertion(same_vpm);
 
-  Vpm vpm1 = boost::choose_param(boost::get_param(np1, internal_np::vertex_point),
+  Vpm vpm1 = parameters::choose_parameter(parameters::get_parameter(np1, internal_np::vertex_point),
                                  get_property_map(boost::vertex_point, tm1));
 
-  Vpm vpm2 = boost::choose_param(boost::get_param(np2, internal_np::vertex_point),
+  Vpm vpm2 = parameters::choose_parameter(parameters::get_parameter(np2, internal_np::vertex_point),
                                  get_property_map(boost::vertex_point, tm2));
 
 // Edge is-constrained maps
-  typedef typename boost::lookup_named_param_def <
+  typedef typename internal_np::Lookup_named_param_def <
     internal_np::edge_is_constrained_t,
     NamedParameters1,
     Corefinement::No_mark<TriangleMesh>//default
   > ::type Ecm1;
 
-  typedef typename boost::lookup_named_param_def <
+  typedef typename internal_np::Lookup_named_param_def <
     internal_np::edge_is_constrained_t,
     NamedParameters2,
     Corefinement::No_mark<TriangleMesh>//default
   > ::type Ecm2;
 
-  Ecm1 ecm1 = boost::choose_param( boost::get_param(np1, internal_np::edge_is_constrained),
+  Ecm1 ecm1 = parameters::choose_parameter( parameters::get_parameter(np1, internal_np::edge_is_constrained),
                                    Corefinement::No_mark<TriangleMesh>() );
-  Ecm2 ecm2 = boost::choose_param( boost::get_param(np2, internal_np::edge_is_constrained),
+  Ecm2 ecm2 = parameters::choose_parameter( parameters::get_parameter(np2, internal_np::edge_is_constrained),
                                    Corefinement::No_mark<TriangleMesh>() );
 
   typedef Corefinement::Ecm_bind<TriangleMesh, Ecm1, Ecm2> Ecm;
@@ -887,12 +887,12 @@ corefine_and_compute_difference(      TriangleMesh& tm1,
   }
 
   // User visitor
-  typedef typename boost::lookup_named_param_def <
+  typedef typename internal_np::Lookup_named_param_def <
     internal_np::graph_visitor_t,
     NamedParameters1,
     Corefinement::Default_visitor<TriangleMesh>//default
   > ::type User_visitor;
-  User_visitor uv( boost::choose_param( boost::get_param(np1, internal_np::graph_visitor),
+  User_visitor uv( parameters::choose_parameter( parameters::get_parameter(np1, internal_np::graph_visitor),
                    Corefinement::Default_visitor<TriangleMesh>() ) );
 
 // surface intersection algorithm call
@@ -945,27 +945,27 @@ namespace experimental {
   typedef typename GetVertexPointMap<TriangleMesh,
                                      NamedParameters>::type Vpm;
 
-  Vpm vpm = boost::choose_param(boost::get_param(np, internal_np::vertex_point),
+  Vpm vpm = parameters::choose_parameter(parameters::get_parameter(np, internal_np::vertex_point),
                                 get_property_map(boost::vertex_point, tm));
 
 // Edge is-constrained maps
-  typedef typename boost::lookup_named_param_def <
+  typedef typename internal_np::Lookup_named_param_def <
     internal_np::edge_is_constrained_t,
     NamedParameters,
     Corefinement::No_mark<TriangleMesh>//default
   > ::type Ecm;
 
 
-  Ecm ecm = boost::choose_param( boost::get_param(np, internal_np::edge_is_constrained),
+  Ecm ecm = parameters::choose_parameter( parameters::get_parameter(np, internal_np::edge_is_constrained),
                                  Corefinement::No_mark<TriangleMesh>() );
 
 // User visitor
-  typedef typename boost::lookup_named_param_def <
+  typedef typename internal_np::Lookup_named_param_def <
     internal_np::graph_visitor_t,
     NamedParameters,
     Corefinement::Default_visitor<TriangleMesh>//default
   > ::type User_visitor;
-  User_visitor uv( boost::choose_param( boost::get_param(np, internal_np::graph_visitor),
+  User_visitor uv( parameters::choose_parameter( parameters::get_parameter(np, internal_np::graph_visitor),
                    Corefinement::Default_visitor<TriangleMesh>() ) );
 
 
@@ -1020,28 +1020,28 @@ namespace experimental {
 // Vertex point maps
   typedef typename GetVertexPointMap<TriangleMesh,
                                      NamedParameters>::type Vpm;
-  Vpm vpm = boost::choose_param(boost::get_param(np, internal_np::vertex_point),
+  Vpm vpm = parameters::choose_parameter(parameters::get_parameter(np, internal_np::vertex_point),
                                 get_property_map(boost::vertex_point, tm));
 // Face index map
   typedef typename GetFaceIndexMap<TriangleMesh,
                                    NamedParameters>::type Fid_map;
-  Fid_map fid_map = boost::choose_param(boost::get_param(np, internal_np::face_index),
+  Fid_map fid_map = parameters::choose_parameter(parameters::get_parameter(np, internal_np::face_index),
                                         get_property_map(boost::face_index, tm));
 // Edge is-constrained maps
-  typedef typename boost::lookup_named_param_def <
+  typedef typename internal_np::Lookup_named_param_def <
     internal_np::edge_is_constrained_t,
     NamedParameters,
     Corefinement::No_mark<TriangleMesh>//default
   > ::type Ecm;
-  Ecm ecm = boost::choose_param( boost::get_param(np, internal_np::edge_is_constrained),
+  Ecm ecm = parameters::choose_parameter( parameters::get_parameter(np, internal_np::edge_is_constrained),
                                  Corefinement::No_mark<TriangleMesh>() );
 // User visitor
-  typedef typename boost::lookup_named_param_def <
+  typedef typename internal_np::Lookup_named_param_def <
     internal_np::graph_visitor_t,
     NamedParameters,
     Corefinement::Default_visitor<TriangleMesh>//default
   > ::type User_visitor;
-  User_visitor uv( boost::choose_param( boost::get_param(np, internal_np::graph_visitor),
+  User_visitor uv( parameters::choose_parameter( parameters::get_parameter(np, internal_np::graph_visitor),
                    Corefinement::Default_visitor<TriangleMesh>() ) );
 
 // surface intersection algorithm call
