@@ -16,8 +16,9 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Number_types/include/CGAL/Quotient.h $
+// $Id: Quotient.h 26c857a 2018-06-13T15:11:45+02:00 Mael Rouxel-Labbé
+// SPDX-License-Identifier: LGPL-3.0+
 //
 //
 // Author(s)     : Stefan Schirra, Sylvain Pion, Michael Hemmer
@@ -90,7 +91,7 @@ class Quotient
   { Split_double<NT>()(n, num, den); }
 
   Quotient(const CGAL_int(NT) & n)
-    : num(n), den(1) {}
+    : num(n), den(NT(1)) {}
 
   template <class T>
   explicit Quotient(const T& n) : num(n), den(1) {}
@@ -402,8 +403,8 @@ quotient_cmp(const Quotient<NT>& x, const Quotient<NT>& y)
     if (diff == 0)
     {
         int msign = CGAL_NTS sign(x.den) * CGAL_NTS sign(y.den);
-        NT leftop  = x.num * y.den * msign;
-        NT rightop = y.num * x.den * msign;
+        NT leftop  = NT(x.num * y.den * msign);
+        NT rightop = NT(y.num * x.den * msign);
         return CGAL_NTS compare(leftop, rightop);
     }
     else
@@ -547,7 +548,7 @@ operator>(const Quotient<NT>& x, const CGAL_double(NT)& y)
 
 template< class NT >
 class Is_valid< Quotient<NT> >
-  : public std::unary_function< Quotient<NT>, bool > {
+  : public CGAL::cpp98::unary_function< Quotient<NT>, bool > {
   public :
     bool operator()( const Quotient<NT>& x ) const {
       return is_valid(x.num) && is_valid(x.den);
@@ -606,7 +607,7 @@ namespace INTERN_QUOTIENT {
   class Sqrt_selector {
     public:
       class Sqrt
-        : public std::unary_function< NT, NT > {
+        : public CGAL::cpp98::unary_function< NT, NT > {
         public:
           NT operator()( const NT& x ) const {
             CGAL_precondition(x > 0);
@@ -638,7 +639,7 @@ public:
 
 
     class Is_square
-        : public std::binary_function< Quotient<NT>, Quotient<NT>&, bool > {
+        : public CGAL::cpp98::binary_function< Quotient<NT>, Quotient<NT>&, bool > {
     public:
         bool operator()( Quotient<NT> x, Quotient<NT>& y ) const {
             NT x_num, x_den, y_num, y_den;
@@ -669,7 +670,7 @@ public:
                             >::type Sqrt;
 
     class Simplify
-      : public std::unary_function< Type&, void > {
+      : public CGAL::cpp98::unary_function< Type&, void > {
       public:
         void operator()( Type& x) const {
             x.normalize();
@@ -687,7 +688,7 @@ template < class NT > class Real_embeddable_traits_quotient_base< Quotient<NT> >
     typedef Quotient<NT> Type;
 
     class Compare
-      : public std::binary_function< Type, Type,
+      : public CGAL::cpp98::binary_function< Type, Type,
                                 Comparison_result > {
       public:
         Comparison_result operator()( const Type& x,
@@ -697,7 +698,7 @@ template < class NT > class Real_embeddable_traits_quotient_base< Quotient<NT> >
     };
 
     class To_double
-      : public std::unary_function< Type, double > {
+      : public CGAL::cpp98::unary_function< Type, double > {
       public:
         double operator()( const Type& x ) const {
         // Original global function was marked with an TODO!!
@@ -729,7 +730,7 @@ template < class NT > class Real_embeddable_traits_quotient_base< Quotient<NT> >
     };
 
     class To_interval
-      : public std::unary_function< Type, std::pair< double, double > > {
+      : public CGAL::cpp98::unary_function< Type, std::pair< double, double > > {
       public:
         std::pair<double, double> operator()( const Type& x ) const {
           Interval_nt<> quot =
@@ -740,7 +741,7 @@ template < class NT > class Real_embeddable_traits_quotient_base< Quotient<NT> >
     };
 
     class Is_finite
-      : public std::unary_function< Type, bool > {
+      : public CGAL::cpp98::unary_function< Type, bool > {
       public:
         bool operator()( const Type& x ) const {
           return CGAL_NTS is_finite(x.num) && CGAL_NTS is_finite(x.den);
@@ -859,6 +860,7 @@ namespace Eigen {
     typedef CGAL::Quotient<NT> Real;
     typedef CGAL::Quotient<NT> NonInteger;
     typedef CGAL::Quotient<NT> Nested;
+    typedef CGAL::Quotient<NT> Literal;
 
     static inline Real epsilon() { return NumTraits<NT>::epsilon(); }
     static inline Real dummy_precision() { return NumTraits<NT>::dummy_precision(); }
