@@ -12,8 +12,9 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Visibility_2/include/CGAL/Rotational_sweep_visibility_2.h $
+// $Id: Rotational_sweep_visibility_2.h 26c857a 2018-06-13T15:11:45+02:00 Mael Rouxel-Labbé
+// SPDX-License-Identifier: GPL-3.0+
 //
 //
 // Author(s):  Kan Huang <huangkandiy@gmail.com>
@@ -72,7 +73,7 @@ private:
   typedef Halfedge_const_handle                         EH;
   typedef std::vector<EH>                               EHs;
 
-  class Less_edge: public std::binary_function<EH, EH, bool> {
+  class Less_edge: public CGAL::cpp98::binary_function<EH, EH, bool> {
     const Geometry_traits_2* geom_traits;
   public:
     Less_edge() {}
@@ -93,7 +94,7 @@ private:
     }
   };
 
-  class Less_vertex: public std::binary_function<VH, VH, bool> {
+  class Less_vertex: public CGAL::cpp98::binary_function<VH, VH, bool> {
     const Geometry_traits_2* geom_traits;
   public:
     Less_vertex() {}
@@ -109,7 +110,7 @@ private:
     }
   };
 
-  class Closer_edge: public std::binary_function<EH, EH, bool> {
+  class Closer_edge: public CGAL::cpp98::binary_function<EH, EH, bool> {
     const Geometry_traits_2* geom_traits;
     Point_2 q;
   public:
@@ -128,8 +129,8 @@ private:
         return 1;
       case LEFT_TURN:
         return 2;
+      default: CGAL_assume(false);
       }
-
       return -1;
     }
 
@@ -206,6 +207,7 @@ private:
             return (Visibility_2::orientation_2(geom_traits, s2, t2, q)
                     == Visibility_2::orientation_2(geom_traits, s2, t2, s1));
         }
+        break;
       case RIGHT_TURN:
         switch (Visibility_2::orientation_2(geom_traits, s1, t1, s2)) {
         case COLLINEAR:
@@ -222,7 +224,9 @@ private:
                 == Visibility_2::orientation_2(geom_traits, s2, t2, s1);
           else
             return true;
+        default: CGAL_assume(false);
         }
+        break;
       case LEFT_TURN:
         switch (Visibility_2::orientation_2(geom_traits, s1, t1, s2)) {
         case COLLINEAR:
@@ -239,9 +243,11 @@ private:
                 == Visibility_2::orientation_2(geom_traits, s2, t2, s1);
           else
             return true;
+        default: CGAL_assume(false);
         }
       }
 
+      CGAL_assume(false);
       return false;
     }
 
@@ -723,7 +729,7 @@ private:
 
   //functor to decide which vertex is swept earlier by the rotational sweeping
   //ray
-  class Is_swept_earlier:public std::binary_function<VH, VH, bool> {
+  class Is_swept_earlier:public CGAL::cpp98::binary_function<VH, VH, bool> {
     const Point_2& q;
     const Geometry_traits_2* geom_traits;
   public:
